@@ -29,12 +29,17 @@
 #include <fcntl.h>
 #include <signal.h>
 #include <stdio.h>
+#include <stdlib.h>
+#include <unistd.h>
+#include <sys/ioctl.h>
 
 #ifdef HAVE_LINUX_FD_H
 #include <linux/fd.h>
 #include <linux/fs.h>
 #endif
 
+#include <string.h>
+
 #include <et/com_err.h>
 #include <ext2fs/ext2_io.h>
 
